@@ -12,7 +12,6 @@
 from __future__ import absolute_import
 
 import os
-import socket
 import sys
 import traceback
 try:
@@ -33,7 +32,7 @@ from celery.exceptions import (
     ImproperlyConfigured, SystemTerminate, TaskRevokedError,
 )
 from celery.five import string_t, values
-from celery.utils import nodename, nodesplit, worker_direct
+from celery.utils import default_nodename, worker_direct
 from celery.utils.imports import reload_from_cwd
 from celery.utils.log import mlevel, worker_logger as logger
 from celery.utils.threads import default_socket_timeout
@@ -65,11 +64,6 @@ def str_to_list(s):
     return s
 
 
-def default_nodename(hostname):
-    name, host = nodesplit(hostname or '')
-    return nodename(name or 'celery', host or socket.gethostname())
-
-
 class WorkController(object):
     """Unmanaged worker instance."""
     app = None
